@@ -13,7 +13,7 @@
  *
  * @link http://exbridge.jp/
  * @author S.Tajima <tajima@exbridge.jp>
- * @version svn:$Id: pettiwork.php 15 2008-07-10 01:34:38Z tshiro $
+ * @version svn:$Id: pettiwork.php 20 2008-07-14 02:16:24Z simizu001 $
  * @copyright 2007-2008 Exbridge,Inc.
  */
 define('DS', DIRECTORY_SEPARATOR);
@@ -101,7 +101,7 @@ try {
             $contents[] = '<?php return array(';
             contents_list($contents);
             $contents[] = ');';
-            @fclose(@fwrite(@fopen($cache_file, 'a'), @implode(chr(10), $contents)));
+            @fclose(@fwrite(@fopen($cache_file, 'w'), @implode(chr(10), $contents)));
         }
         $cache_list = include($cache_file);
         foreach ($cache_list as $file) {
