@@ -14,7 +14,7 @@
  * @link http://exbridge.jp/
  * @author      S.Tajima <tajima@exbridge.jp> 2007N0905
  *              S.Tajima <tajima@exbridge.jp> 2007N1105
- * @version svn:$Id: xbpwXML.php 3 2008-07-01 10:08:07Z tshiro $
+ * @version svn:$Id: xbpwXML.php 21 2008-07-14 08:08:42Z tshiro $
  * @copyright 2007-2008 Exbridge,Inc.
  */
 class xbpwXML extends DOMDocument {
@@ -32,9 +32,9 @@ class xbpwXML extends DOMDocument {
     {
         parent::__construct('1.0', 'UTF-8');
         //load
-        $this->formatOutput = true;// o͂͂ꂢɐ`łˁB
         $this->preserveWhiteSpace = false;//󔒂ɔY܂ꂽ܂BBBȂ̂
         $this->load($file);
+        $this->formatOutput = true;// o͂͂ꂢɐ`łˁB
         $this->_dpath = new DOMXPath($this);
         $this->_xpath = simplexml_import_dom($this);
     }
@@ -45,7 +45,13 @@ class xbpwXML extends DOMDocument {
     function getXML()
     {
         if ($this->_xpath) {
-            return $this->_xpath->asXML();
+            $xmlstr = $this->_xpath->asXML();
+            $doc = new DOMDocument('1.0', 'UTF-8');
+            $doc->preserveWhiteSpace = false;
+            $dom = $doc->loadXML($xmlstr);
+            $doc->formatOutput = true;
+            $dom = $doc->appendChild($dom);
+            return $doc->saveXML();
         }
         return '';
     }
