@@ -13,7 +13,7 @@
  *
  * @link http://exbridge.jp/
  * @author S.Tajima <tajima@exbridge.jp>
- * @version svn:$Id: function.glib.php 17 2008-07-12 02:00:15Z tshiro $
+ * @version svn:$Id: function.glib.php 26 2008-07-19 04:47:18Z tshiro $
  * @copyright 2007-2008 Exbridge,Inc.
  */
 
@@ -87,16 +87,6 @@ function LPAD($val1, $val2)
     return str_pad($val1, $val2, '0', STR_PAD_LEFT);
 }
 
-/**
- * 右詰め処理
- *
- * @return string
- */
-function RPAD($val1, $val2)
-{
-    return str_pad($val1, $val2, '0', STR_PAD_RIGHT);
-}
-
 /**
  * 全角、半角混在の長さ取得
  * （UTF-8でもEUCでもSJISでも同じ結果がほしい）
@@ -317,3 +307,33 @@ function rm($file) {
     require_once(PW_ROOT_DIR . DS . 'vendors' . DS . 'pear' . DS . 'System.php');
     System::rm("-r " . $file);
 }
+
+/**
+ * Post Url.
+ * @access public
+ */
+function get_url_contents($url, $param = null, $option_headers = null) {
+    $params = array();
+    $params['http']['method'] = 'POST';
+    if (!is_null($param)) {
+        $params['http']['content'] = str_replace('amp;', '', http_build_query($param));
+    }
+    if (!is_null($option_headers)) {
+        $params['http']['header'] = $option_headers;
+    }
+    return trim(file_get_contents($url, false, stream_context_create($params)));
+}
+
+/**
+ * isMoble.
+ * @access public
+ */
+function isMobile() {
+    if (PW_TEMPLATE_AUTO_CONVERT) {
+        require_once(PW_VENDORS_DIR . DS . 'pear' . DS . 'Net'. DS . 'UserAgent'. DS . 'Mobile.php');
+        if (Net_UserAgent_Mobile::isMobile()) {
+            return true;
+        }
+    }
+    return false;
+}
