@@ -13,7 +13,7 @@
  *
  * @link http://exbridge.jp/
  * @author S.Tajima <tajima@exbridge.jp>
- * @version svn:$Id: xbpwDefaultView.php 3 2008-07-01 10:08:07Z tshiro $
+ * @version svn:$Id: xbpwDefaultView.php 27 2008-07-19 06:42:45Z tshiro $
  * @copyright 2007-2008 Exbridge,Inc.
  */
 class xbpwDefaultView extends xbpwAbstractView
@@ -118,14 +118,6 @@ class xbpwDefaultView extends xbpwAbstractView
         }
         $pw->_js_headers = implode("\n", $js_headers)."\n";
 
-        $conv = false;
-        if (PW_TEMPLATE_AUTO_CONVERT) {
-            require_once(PW_VENDORS_DIR . DS . 'pear' . DS . 'Net'. DS . 'UserAgent'. DS . 'Mobile.php');
-            if (Net_UserAgent_Mobile::isMobile()) {
-                $conv = true;
-            }
-        }
-
         $layout = $this->templatesDir . DS . $template;
         $contents = null;
         if (file_exists($default_layout)) {
@@ -133,9 +125,6 @@ class xbpwDefaultView extends xbpwAbstractView
             require_once $layout;
             $pw->contents = ob_get_contents();
             ob_end_clean();
-            //if ($conv) {
-            //    $pw->contents = mb_convert_encoding($pw->contents, PW_MOBILE_ENCODE, PW_ENCODE);
-            //}
             $contents = $default_layout;
         }
         else {
@@ -147,7 +136,7 @@ class xbpwDefaultView extends xbpwAbstractView
         require_once $contents;
         $this->result = ob_get_contents();
         ob_end_clean();
-        if ($conv) {
+        if (isMobile()) {
             $this->result = mb_convert_encoding($this->result, PW_MOBILE_ENCODE, PW_ENCODE);
         }
         return true;
