@@ -13,7 +13,7 @@
  *
  * @link http://exbridge.jp/
  * @author S.Tajima <tajima@exbridge.jp>
- * @version svn:$Id: xbpwController.php 16 2008-07-10 12:10:55Z tshiro $
+ * @version svn:$Id: xbpwController.php 26 2008-07-19 04:47:18Z tshiro $
  * @copyright 2007-2008 Exbridge,Inc.
  */
 class xbpwController
@@ -96,6 +96,7 @@ class xbpwController
 
     var $_pw_meta_header = array();
 
+    var $_pw_from_mobile = false;
     /**
      * Creates new instance.
      * @access public
@@ -127,6 +128,9 @@ class xbpwController
                 $this->_pw_validator_class = PW_APP . 'Validator';
             }
         }
+
+        $this->_pw_from_mobile = isMobile();
+
         // populate http request
         $this->_pw_request =& xbpwRequest::factory($this->_pw_action_key);
         $this->_pw_params = $this->_pw_request->getParameters();
@@ -424,7 +428,7 @@ class xbpwController
             $url = $_SERVER['PHP_SELF'] . '?action=' . $action;
             $query = array();
             foreach ($params as $key => $val) {
-                $query[] = urlencode($key) . '=' . urlencode($val);
+                $query[] = urlencode($key) . '=' . urlencode($this->_convertEncoding($val));
             }
             if(count($query)>0) {
                 $url .= '&' . implode('&', $query);
@@ -434,7 +438,7 @@ class xbpwController
             $url = convert_uri($this->_pw_params[$this->_pw_webaccess_key] . '/' . $action);
             $query = array();
             foreach ($params as $key => $val) {
-                $query[] = urlencode($val);
+                $query[] = urlencode($this->_convertEncoding($val));
             }
             if(count($query)>0) {
                 $url .= '/' . implode('/', $query);
@@ -472,8 +476,8 @@ class xbpwController
         //preg_match ("/".$regex."/i", $uri, $match);
         if (is_null($this->_pw_params[$this->_pw_webaccess_key])) {
             $query = array();
-            foreach ($params as $key => $value) {
-                $query[] = urlencode($key) . '=' . urlencode($value);
+            foreach ($params as $key => $val) {
+                $query[] = urlencode($key) . '=' . urlencode($this->_convertEncoding($val));
             }
             if (count($query)>0) {
                 if(!strpos($path,'?')){
@@ -488,7 +492,7 @@ class xbpwController
         else {
             $query = array();
             foreach ($params as $key => $val) {
-                $query[] = urlencode($val);
+                $query[] = urlencode($this->_convertEncoding($val));
             }
             if(count($query)>0) {
                 $path .= '/' . implode('/', $query);
@@ -498,6 +502,16 @@ class xbpwController
         }
     }
 
+    /**
+     * Post to relative-path.
+     * @access public
+     */
+    function postToPath($path, $params = array(), $option_headers = null)
+    {
+        echo get_url_contents('http://' . $_SERVER['HTTP_HOST'] . convert_uri($path), $params, $option_headers);
+        return PW_TERMINATE_PROCESS;
+    }
+
     /**
      * Redirect to URL.
      * @access public
@@ -513,6 +527,15 @@ class xbpwController
         return PW_CONTINUE_PROCESS;
     }
 
+    /**
+     * Post to Url.
+     * @access public
+     */
+    function postToUrl($url, $param, $option_headers = null) {
+        echo get_url_contents($url, $param, $option_headers);
+        return PW_TERMINATE_PROCESS;
+    }
+
     /**
      * validate.
      * @access public
@@ -908,4 +931,14 @@ class xbpwController
         }
         return explode('::', $buf);
     }
+
+    /**
+     * @access private
+     */
+    function _convertEncoding($val) {
+        if ($this->_pw_from_mobile) {
+            return mb_convert_encoding($val, PW_MOBILE_ENCODE, PW_ENCODE);
+        }
+        return $val;
+    }
 }
