@@ -13,7 +13,7 @@
  *
  * @link http://exbridge.jp/
  * @author S.Tajima <tajima@exbridge.jp>
- * @version svn:$Id: xbpwRequest.php 3 2008-07-01 10:08:07Z tshiro $
+ * @version svn:$Id: xbpwRequest.php 26 2008-07-19 04:47:18Z tshiro $
  * @copyright 2007-2008 Exbridge,Inc.
  */
 class xbpwRequest
@@ -169,7 +169,12 @@ class xbpwRequest
      */
     function setParam($key, $val)
     {
-        $this->_params[$key] = $val;
+        if (isMobile()) {
+            $this->_params[$key] = mb_convert_encoding($val, PW_ENCODE, PW_MOBILE_ENCODE);
+        }
+        else {
+            $this->_params[$key] = $val;
+        }
     }
 
     /**
